@@ -56,6 +56,19 @@ The location of the I<names.dmp> file. Filehandles are also allowed. I<Mandatory
 
 The location of the I<nodes.dmp> file. Filehandles are also allowed. I<Mandatory>.
 
+=item synonyms
+
+An array reference listing the categories of synonymous names made available to methods C<get_taxid_from_name> and C<get_taxonomy_from_name>. This parameter is optional and set to C<['synonym']> by default.
+
+As of May 2015, meaningful values are: I<acronym>, I<anamorph>, I<authority>, I<blast name>, I<common name>, I<equivalent name>, I<genbank acronym>, I<genbank anamorph>, I<genbank common name>, I<genbank synonym>, I<in-part>, I<includes>, I<misnomer>, I<misspelling>, I<synonym>, I<teleomorph>, I<type material>.
+
+ my $taxDB = Bio::LITE::Taxonomy::NCBI->new (
+                                             db=>"NCBI",
+                                             names=> "/path/to/names.dmp",
+                                             nodes=>"/path/to/nodes.dmp",
+                                             synonyms=>['anamorph','teleomorph','synonym']
+                                            );
+
 =item dict
 
 You can query the tree using C<GI>s directly instead of C<Taxid>s. For doing this, you should provide the NCBIs GI to Taxid mapper in binary format as explained in L<Bio::LITE::Taxonomy::NCBI::Gi2taxid>. I<Optional>
@@ -113,12 +126,15 @@ L<Bio::DB::Taxonomy::*> - Bioperl alternative for NCBI taxonomies.
 =head1 AUTHOR
 
 Miguel Pignatelli
-
 Any comments or suggestions should be addressed to emepyc@gmail.com
 
+=head1 CONTRIBUTORS
+
+Denis Baurain (denis.baurain -AT- ulg.ac.be) 
+
 =head1 LICENSE
 
-Copyright 2009 Miguel Pignatelli, all rights reserved.
+Copyright 2015 Miguel Pignatelli, all rights reserved.
 
 This library is free software; you may redistribute it and/or modify it under the same terms as Perl itself.
 
@@ -136,7 +152,7 @@ use Carp qw/croak/;
 #}
 use base qw(Bio::LITE::Taxonomy);
 
-our $VERSION = 0.09;
+our $VERSION = 0.1;
 
 use constant FS => '\t\|\t';
 use constant RS => '\t\|\n';
@@ -148,8 +164,7 @@ sub new {
   defined $args{'nodes'} or croak "Need the file nodes.dmp";
   defined $args{'names'} or croak "Need the file names.dmp";
 
-  @opts{qw/nodesFile namesFile/} = @args{qw/nodes names/};
-
+  @opts{qw/nodesFile namesFile synList/} = @args{qw/nodes names synonyms/};
   my $self = bless \%opts, $class;
   $self->_build_taxonomy();
   if (defined $args{dict}) {
@@ -191,13 +206,14 @@ sub _name_nodes {
   } else {
     open $nodesNames, "<", $namesFile or croak $!;
   }
+  my %wanted = map { $_ => 1 } @{$self->{synList} // ['synonym']};
   while (<$nodesNames>){
     chomp;
     my ($taxId,$taxName,$comment) = _process_tax_name ($_);
-    if ($comment eq "scientific name"){
+    if ($comment eq 'scientific name'){
       ${$self->{nodes}->{$taxId}}{name} = $taxName;
       $self->{names}->{$taxName} = $taxId;
-    } elsif ($comment eq "synonym") {
+    } elsif ($wanted{$comment}) {
       $self->{names}->{$taxName} = $taxId;
     }
   }
